
###############
Example Gallery
###############

.. currentmodule:: tropycal

Choose from one of the following examples for how to use Tropycal for performing analyses:

.. toctree::
   :maxdepth: 1

   samples/tracks.storm
   samples/tracks.tornado
   samples/tracks.TrackDataset

* :ref:`modindex`
* :ref:`genindex`